Deletes all locally cached NOAA data files. The next call to any data function will re-download from the NCEI API.
See also
Other data access:
list_datasets(),
list_datatypes(),
noaa_get()
Deletes all locally cached NOAA data files. The next call to any data function will re-download from the NCEI API.
Other data access:
list_datasets(),
list_datatypes(),
noaa_get()